pub struct AnyError { /* private fields */ }Expand description
AnyError is a serializable wrapper Error.
It is can be used to convert other Error into a serializable Error for transmission,
with most necessary info kept.
let e = AnyError::new(&fmt::Error{}).add_context(|| "example");
assert_eq!("core::fmt::Error: an error occurred when formatting an argument while: example", e.to_string());Implementations
sourceimpl AnyError
impl AnyError
sourcepub fn new<E>(e: &E) -> Self where
E: Error + 'static,
pub fn new<E>(e: &E) -> Self where
E: Error + 'static,
Convert some Error to AnyError.
- If there is a
source()in the input error, it is also converted to AnyError, recursively. - A new backtrace will be built if there is not.
pub fn from_dyn(e: &(dyn Error + 'static), typ: Option<String>) -> Self
pub fn with_backtrace(self) -> Self
pub fn add_context<D: Display, F: FnOnce() -> D>(self, ctx: F) -> Self
pub fn get_type(&self) -> Option<&str>
pub fn backtrace(&self) -> Option<&str>